@@ -17,7 +17,7 @@ Usage::
     list_targets_paginator: ListTargetsPaginator = client.get_paginator("list_targets")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Generator, List, TYPE_CHECKING
+from typing import Iterator, List, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_codestar_notifications.type_defs import (
     ListEventTypesFilterTypeDef,
@@ -42,7 +42,7 @@ class ListEventTypesPaginator(Boto3Paginator):
         self,
         Filters: List[ListEventTypesFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListEventTypesResultTypeDef, None, None]:
+    ) -> Iterator[ListEventTypesResultTypeDef]:
         """
         [ListEventTypes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes.paginate)
         """
@@ -57,7 +57,7 @@ class ListNotificationRulesPaginator(Boto3Paginator):
         self,
         Filters: List[ListNotificationRulesFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListNotificationRulesResultTypeDef, None, None]:
+    ) -> Iterator[ListNotificationRulesResultTypeDef]:
         """
         [ListNotificationRules.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules.paginate)
         """
@@ -72,7 +72,7 @@ class ListTargetsPaginator(Boto3Paginator):
         self,
         Filters: List[ListTargetsFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListTargetsResultTypeDef, None, None]:
+    ) -> Iterator[ListTargetsResultTypeDef]:
         """
         [ListTargets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets.paginate)
         """
